Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2007-04-04 17:18:41 +0400
committerCampbell Barton <ideasman42@gmail.com>2007-04-04 17:18:41 +0400
commitafdd54fa3720c267f30e48ed45c449d80449bac0 (patch)
tree3192044fa53f6e1fd3d1b0256963c2d4c090d700 /source/blender/src/editview.c
parent203e6ed82b444786d7999e88cebef84d6d429765 (diff)
moved source and text to american spelling
* colour -> color * centre -> center * normalise -> normalize * modelling -> modeling
Diffstat (limited to 'source/blender/src/editview.c')
-rw-r--r--source/blender/src/editview.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/source/blender/src/editview.c b/source/blender/src/editview.c
index 2fc9cee5138..3b59b2fbd74 100644
--- a/source/blender/src/editview.c
+++ b/source/blender/src/editview.c
@@ -635,7 +635,7 @@ static char interpret_move(short mcord[][2], int count)
/* new method:
*
* starting from end points, calculate centre with maximum distance
* dependant at the angle s / g / r is defined
*/
@@ -1278,7 +1278,7 @@ void mouse_select(void)
getmouseco_areawin(mval);
/* This block uses the control key to make the object selected by its centre point rather then its contents */
if(G.obedit==0 && (G.qual & LR_CTRLKEY)) {
/* note; shift+alt goes to group-flush-selecting */
@@ -2203,7 +2203,7 @@ void fly(void)
/* the dist defines a vector that is infront of the offset
to rotate the view about.
this is no good for fly mode because we
- want to rotate about the viewers centre.
+ want to rotate about the viewers center.
but to correct the dist removal we must
alter offset so the view dosent jump. */
@@ -635,7 +635,7 @@ static char interpret_move(short mcord[][2], int count)
/* new method:
*
- * starting from end points, calculate centre with maximum distance
+ * starting from end points, calculate center with maximum distance
* dependant at the angle s / g / r is defined
*/
@@ -1278,7 +1278,7 @@ void mouse_select(void)
getmouseco_areawin(mval);
- /* This block uses the control key to make the object selected by its centre point rather then its contents */
+ /* This block uses the control key to make the object selected by its center point rather then its contents */
if(G.obedit==0 && (G.qual & LR_CTRLKEY)) {
/* note; shift+alt goes to group-flush-selecting */